==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ar" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>إنشاء جدول بيانات</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>إنشاء جدول بيانات جديد</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>محاذاة لأسفل</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>محاذاة محتويات الخلايا المحددة لأسفل</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>محاذاة للوسط</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation type="unfinished">Center-align contents of selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>محاذاة لليسار</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>محاذاة محتويات الخلايا المحددة لليسار</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>محاذاة لليمين</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>محاذاة محتويات الخلايا المحددة لليمين</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>محاذاة لأعلى</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation type="unfinished">Top-align contents of selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation type="unfinished">Vertically center-align</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation type="unfinished">Vertically center-align contents of selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>تصدير جدول البيانات</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>تصدير جدول البيانات إلى ملف CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>استيراد جدول البيانات</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>استيراد ملف CSV إلى جدول البيانات</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>دمج الخلايا</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>دمج الخلايا المحددة في جدول البيانات</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation type="unfinished">Set alias</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation type="unfinished">Set alias for selected cell</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>تقسيم الخلية</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>تقسيم الخلايا المدمجة مسبقاً في جدول البيانات</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>نص عريض</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>تعيين نص عريض في الخلايا المحددة</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>نص مائل</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>تعيين نص مائل في الخلايا المحددة</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>تسطير النص</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation type="unfinished">Underline text in selected cells</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation type="unfinished">Custom Color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>خصائص الخلية</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;لون</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>نص</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>الخلفية</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;المحاذاة</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>يسار</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>مركز</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>يمين</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>أعلى</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>أسفل</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation type="unfinished">&amp;Style</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>عريض</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>مائل</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>تسطير</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;عرض الوحدة</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation type="unfinished">Unit string</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation type="unfinished">A&amp;lias</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation type="unfinished">Alias for this cell</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>الكل (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>استيراد ملف</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>تصدير ملف</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>محتويات الخلية</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>إظهار جدول البيانات</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>تعيين لون المقدمة للخلية(خلايا)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>تقوم بتعيين لون المقدمة لخلية(خلايا) جدول البيانات</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>تعيين لون الخلفية للخلية(خلايا)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>تقوم بتعيين لون الخلفية لخلية(خلايا) جدول البيانات</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>أسود</translation>
    </message>
    <message>
      <source>White</source>
      <translation>أبيض</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>أحمر</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>أحمر داكن</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>أخضر</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>أخضر داكن</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>أزرق</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>أزرق داكن</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>سماوي</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>سماوي داكن</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>أرجواني</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>أرجواني داكن</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>أصفر</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>أصفر داكن</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>رمادي</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>رمادي داكن</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>رمادي فاتح</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>مخصص</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>إستمارة</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;المحتويات</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>غير مسمى</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>إدراج صفوف</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>إزالة صفوف</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>إدراج أعمدة</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>إزالة أعمدة</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>خصائص...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1+dfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>إنشاء جدول بيانات</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>إنشاء جدول بيانات جديد</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>محاذاة لأسفل</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>محاذاة محتويات الخلايا المحددة لأسفل</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>محاذاة للوسط</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>محتويات الخلايا المحددة المحاذاة في الوسط</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>محاذاة لليسار</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>محاذاة محتويات الخلايا المحددة لليسار</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>محاذاة لليمين</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>محاذاة محتويات الخلايا المحددة لليمين</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>محاذاة لأعلى</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>محتويات الخلايا المحددة المحاذاة لأعلى</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>محاذاة للوسط رأسيا</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation>محتويات الخلايا المحددة المحاذاة للوسط رأسيا</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>تصدير جدول البيانات</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>تصدير جدول البيانات إلى ملف CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>استيراد جدول البيانات</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>استيراد ملف CSV إلى جدول البيانات</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>دمج الخلايا</translation>
    </message>
    <message>
      <source>Merge selected cells</source>
      <translation>ادمج الخلايا المحددة</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>عرف الاسم المستعار</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>عرف الاسم المستعار للخلية المحددة</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>تقسيم الخلية</translation>
    </message>
    <message>
      <source>Split previously merged cells</source>
      <translation>افصل الخلايا المدمجة سابقا</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>نص عريض</translation>
    </message>
    <message>
      <source>Set text in selected cells bold</source>
      <translation>اجعل النص في الخلايا المحددة بالخط العريض</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>نص مائل</translation>
    </message>
    <message>
      <source>Set text in selected cells italic</source>
      <translation>اجعل النص في الخلايا المحددة بالخط المائل</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>تسطير النص</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation>ضع خطا تحت النص في الخلايا المحددة</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation>لون معرف</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <source>Merge cells</source>
      <translation>دمج الخلايا</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>تقسيم الخلية</translation>
    </message>
    <message>
      <source>Left-align cell</source>
      <translation>محاذاة الخلية لليسار</translation>
    </message>
    <message>
      <source>Center cell</source>
      <translation>توسيط الخلية</translation>
    </message>
    <message>
      <source>Right-align cell</source>
      <translation>محاذاة الخلية لليمين</translation>
    </message>
    <message>
      <source>Top-align cell</source>
      <translation>محاذاة الخلية للأعلى</translation>
    </message>
    <message>
      <source>Bottom-align cell</source>
      <translation>محاذاة الخلية للأسفل</translation>
    </message>
    <message>
      <source>Vertically center cells</source>
      <translation>محاذاة الخلايا للوسط رأسيًا</translation>
    </message>
    <message>
      <source>Set bold text</source>
      <translation>تعيين نص بالخط العريض</translation>
    </message>
    <message>
      <source>Set italic text</source>
      <translation>تعيين نص مائل</translation>
    </message>
    <message>
      <source>Set underline text</source>
      <translation>تسطير النص</translation>
    </message>
    <message>
      <source>Create Spreadsheet</source>
      <translation>إنشاء جدول بيانات</translation>
    </message>
    <message>
      <source>Set cell properties</source>
      <translation>تعيين خصائص الخلية</translation>
    </message>
    <message>
      <source>Edit cell</source>
      <translation>تعديل الخلية</translation>
    </message>
    <message>
      <source>Insert rows</source>
      <translation>إدراج صفوف</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>إزالة صفوف</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>إدراج أعمدة</translation>
    </message>
    <message>
      <source>Clear cell(s)</source>
      <translation>مسح الخلية (خلايا)</translation>
    </message>
    <message>
      <source>Set foreground color</source>
      <translation>تعيين اللون الأمامي</translation>
    </message>
    <message>
      <source>Set background color</source>
      <translation>تعيين لون الخلفية</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>خصائص الخلية</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;لون</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>نص</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>الخلفية</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;المحاذاة</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>أفقيا</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>يسار</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>مركز</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>يمين</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>رأسيا</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>أعلى</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>أسفل</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>نمط</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>عريض</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>مائل</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>تسطير</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;عرض الوحدة</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>وحدة سلسلة</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>الاسم المستعار</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>الاسم المستعار لهذه الخلية</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>الكل (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>استيراد ملف</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>تصدير ملف</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>إظهار جدول البيانات</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>تعيين لون المقدمة للخلية(خلايا)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>تقوم بتعيين لون المقدمة لخلية(خلايا) جدول البيانات</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>تعيين لون الخلفية للخلية(خلايا)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>تقوم بتعيين لون الخلفية لخلية(خلايا) جدول البيانات</translation>
    </message>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
    <message>
      <source>Spreadsheet does not support range selection when pasting.
Please select one cell only.</source>
      <translation>جدول البيانات لا يدعم تحديد النطاق عند اللصق.
الرجاء تحديد خلية واحدة فقط.</translation>
    </message>
    <message>
      <source>Copy &amp; Paste failed</source>
      <translation>فشل النسخ واللصق</translation>
    </message>
    <message>
      <source>Alias contains invalid characters!</source>
      <translation>الاسم المستعار يحتوي على أحرف غير صالحة!</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>الرجوع إلى الخلية بواسطة الاسم المستعار، على سبيل المثال
Spreadsheet.my_alias_name بدلاً من Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>أسود</translation>
    </message>
    <message>
      <source>White</source>
      <translation>أبيض</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>أحمر</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>أحمر داكن</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>أخضر</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>أخضر داكن</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>أزرق</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>أزرق داكن</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>سماوي</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>سماوي داكن</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>أرجواني</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>أرجواني داكن</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>أصفر</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>أصفر داكن</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>رمادي</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>رمادي داكن</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>رمادي فاتح</translation>
    </message>
    <message>
      <source>Custom Color</source>
      <translation>لون معرف</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>إستمارة</translation>
    </message>
    <message>
      <source>&amp;Content:</source>
      <translation>والمحتوى:</translation>
    </message>
    <message>
      <source>&amp;Alias:</source>
      <translation>والاسم المستعار:</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>الرجوع إلى الخلية بواسطة الاسم المستعار، على سبيل المثال
Spreadsheet.my_alias_name بدلاً من Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>غير مسمى</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>إدراج صفوف</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>إزالة صفوف</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>إدراج أعمدة</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>إزالة أعمدة</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>خصائص...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>جدول البيانات</translation>
    </message>
  </context>
</TS>
